import { getToken } from 'utils/store'
import { ElNotification } from 'element-plus'
export default ({ url, method, data, params, type }) => {
  const baseURL = import.meta.env.PROD ? import.meta.env.VITE_BASE_API : ''
  method = method.toUpperCase()
  url = baseURL + url
  let dataStr = '' // 数据拼接字符串
  if (method == 'GET') {
    if (typeof (params) == 'object') {
      Object.keys(params).forEach(key => {
        dataStr += key + '=' + params[key] + '&'
      })
    }
    if (dataStr !== '') {
      dataStr = dataStr.substr(0, dataStr.lastIndexOf('&'))
    }
    url = url + '?' + dataStr
  } else {
    Object.keys(data).forEach(key => {
      dataStr += key + '=' + data[key] + '&'
    })
    dataStr = dataStr.substr(0, dataStr.lastIndexOf('&'))
  }
  const xhr = new XMLHttpRequest()

  xhr.open(method, url, true)
  xhr.responseType = 'arraybuffer'
  xhr.onload = function () {
    if (this.status === 200) {
      // 提取文件名
      let filename = ''
      const disposition = xhr.getResponseHeader('Content-disposition')
      if (disposition && disposition.indexOf('attachment') !== -1) {
        const filenameRegex = /filename[^;=\n]*=((['"]).*?\2|[^;\n]*)/
        const matches = filenameRegex.exec(disposition)
        if (matches != null && matches[1]) filename = decodeURI(matches[1].replace(/['"]/g, ''))
      }
      const type2 = xhr.getResponseHeader('Content-Type')

      if (typeof File === 'undefined' && typeof Blob === 'undefined') {
        alert('当前浏览器不支持下载，请使用最新浏览器重试')
        return
      }

      const blob = typeof File === 'function'
        ? new File([this.response], filename, { type: type2 })
        : new Blob([this.response], { type: type2 })
      if (typeof window.navigator.msSaveBlob !== 'undefined') {
        window.navigator.msSaveBlob(blob, filename)
      } else {
        const URL = window.URL || window.webkitURL
        const downloadUrl = URL.createObjectURL(blob)
        if (filename) {
          const a = document.createElement('a')
          if (typeof a.download === 'undefined') {
            window.location = downloadUrl
          } else {
            a.href = downloadUrl
            a.download = filename
            document.body.appendChild(a)
            a.click()
          }
        } else {
          debugger
          const errorRes = JSON.parse(String.fromCharCode.apply(null, new Uint8Array(xhr.response)))
          errorRes.message = decodeURI(escape(errorRes.message))
          if (errorRes.message != '') {
            ElNotification({
              title: '请求出错',
              message: errorRes.message,
              type: 'error'
            })
          } else {
            ElNotification({
              title: '文件下载失败',
              type: 'error'
            })
          }
        }
        setTimeout(function () { URL.revokeObjectURL(downloadUrl) }, 100)
      }
    } else {
      ElNotification({
        title: '文件下载失败',
        message: xhr.statusText,
        type: 'error'
      })
    }
  }
  xhr.setRequestHeader('Authorization', ('Bearer ' + getToken()) || '')
  xhr.setRequestHeader('token', getToken() || '')
  if (type == 'JSON') {
    xhr.setRequestHeader('Accept', 'application/json')
    xhr.setRequestHeader('Content-type', 'application/json;charset=UTF-8')
  } else {
    xhr.setRequestHeader('Content-type', 'application/x-www-form-urlencoded')
  }
  if (method == 'POST') {
    if (type == 'JSON') {
      const params = JSON.stringify(data)
      xhr.send(params)
    } else {
      xhr.send(dataStr)
    }
  } else {
    xhr.send(dataStr)
  }
}
